@@ -37,6 +37,9 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 18, 0) || defined(RHEL_72)
 #include <drm/drm_plane_helper.h>
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0)
+#include <drm/drm_probe_helper.h>
+#endif
 
 #include "vboxvideo.h"
 
@@ -169,6 +172,8 @@ static bool vbox_set_up_input_mapping(struct vbox_private *vbox)
 			if (to_vbox_crtc(crtci)->crtc_id != 0)
 				continue;
 
+			if (!CRTC_FB(crtci))
+				break;
 			vbox->single_framebuffer = true;
 			vbox->input_mapping_width = CRTC_FB(crtci)->width;
 			vbox->input_mapping_height = CRTC_FB(crtci)->height;
